CHANGELOG
=========

1.0.0 - 2025-05-26
------------------

Move project to own repository and release as namespace plugin.

Contributed by [Frederik Elwert](https://github.com/frederik-elwert) via [PR #1](https://github.com/pelican-plugins/i18n-subsites/pull/1/)


